"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          15-05-2018
//      Created for Project :   FLAME
"""

from pyramid.config import Configurator
from pyramid.settings import asbool

from clmcservice.utilities import RUNNING_FLAG, MALFORMED_FLAG


def main(global_config, **settings):
    """
    This function returns a Pyramid WSGI application.
    """

    # a conversion is necessary so that the configuration values of the aggregator are stored with the right type instead of strings
    aggregator_running = asbool(settings.get(RUNNING_FLAG, False))
    settings[RUNNING_FLAG] = asbool(aggregator_running)

    aggregator_report_period = int(settings.get('aggregator_report_period', 5))
    settings['aggregator_report_period'] = aggregator_report_period

    settings[MALFORMED_FLAG] = False

    config = Configurator(settings=settings)

    config.add_route('aggregator_config', '/aggregator/config')
    config.add_view('clmcservice.views.AggregatorConfig', attr='get', request_method='GET')
    config.add_view('clmcservice.views.AggregatorConfig', attr='put', request_method='PUT')

    config.add_route('aggregator_controller', '/aggregator/control')
    config.add_view('clmcservice.views.AggregatorController', attr='get', request_method='GET')
    config.add_view('clmcservice.views.AggregatorController', attr='put', request_method='PUT')

    config.scan()
    return config.make_wsgi_app()
